window.Gleam.initSearch([{"doc":"glentities","title":"glentities","content":"# glentities\n\n[![Package Version](https://img.shields.io/hexpm/v/glentities)](https://hex.pm/packages/glentities)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glentities/)\n\nAn HTML entity encoder/decoder for Gleam.\n\nEntities can be encoded using named or hex entity references. Named entity references use the WHATWG &quot;Named character references&quot; list available at [https://html.spec.whatwg.org/multipage/named-characters.html#named-character-references](https://html.spec.whatwg.org/multipage/named-characters.html#named-character-references).\n\n## Quick start\n\n```gleam\nimport glentities\n\nglentities.encode(&quot;&lt;/html&gt;&quot;, glentities.HTMLBody) // &quot;&amp;lt;/html&amp;gt;&quot;\nglentities.encode(&quot;&lt;/html&gt;&quot;, glentities.Named)    // &quot;&amp;lt;&amp;sol;html&amp;gt;&quot;\nglentities.encode(&quot;&lt;/html&gt;&quot;, glentities.Hex)      // &quot;&amp;#x3C;&amp;#x2F;html&amp;#x3E;&quot;\n\nglentities.decode(&quot;&amp;#x3C;&amp;#x2F;html&amp;#x3E;&quot;)       // &quot;&lt;/html&gt;&quot;\nglentities.decode(&quot;&amp;lt;&amp;sol;html&amp;gt;&quot;)            // &quot;&lt;/html&gt;&quot;\n```\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add glentities\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/glentities&gt;.\n","url":"index.html"},{"doc":"glentities","title":"EncodeMode","content":"pub type EncodeMode {\n  Named\n  Hex\n  HTMLBody\n}\n\nNamed\n Encode all characters that have a specified named entity using that name, except tab and newline.\n\nHex\n Encode all characters using hex entities, except a-z, A-Z, 0-9, newline, tab, carriage return, and space.\n\nHTMLBody\n Encode only the necessary characters when the output target is HTML element or attribute content.\n\n This means `&amp;`, `&lt;`, `&gt;`, `&#39;`, and `&quot;`.\n\n Note! Not suitable for outputting inside `&lt;style&gt;`, `&lt;script&gt;` elements.\n\nSynonyms:\nglentities.EncodeMode\nglentities EncodeMode","url":"glentities.html#EncodeMode"},{"doc":"glentities","title":"decode","content":"pub fn decode(text: String) -&gt; String\n Decode any HTML entities in the given string.\nSynonyms:\nglentities.decode\nglentities decode","url":"glentities.html#decode"},{"doc":"glentities","title":"decode_dec","content":"pub fn decode_dec(entity: String) -&gt; String\n Decode given entity (without surrounding `&amp;#` and `;`) as decimal entity. Returns original if cannot be decoded.\nSynonyms:\nglentities.decode_dec\nglentities decode_dec","url":"glentities.html#decode_dec"},{"doc":"glentities","title":"decode_hex","content":"pub fn decode_hex(entity: String) -&gt; String\n Decode given entity (without surrounding `&amp;#x` and `;`) as hex entity. Returns original if cannot be decoded.\nSynonyms:\nglentities.decode_hex\nglentities decode_hex","url":"glentities.html#decode_hex"},{"doc":"glentities","title":"decode_named","content":"pub fn decode_named(entity: String) -&gt; String\n Decode given entity (without surrounding `&amp;` and `;`) as a named entity. Returns original if it doesn&#39;t match any entity name.\nSynonyms:\nglentities.decode_named\nglentities decode_named","url":"glentities.html#decode_named"},{"doc":"glentities","title":"encode","content":"pub fn encode(text: String, mode: EncodeMode) -&gt; String\n Encode characters in text as HTML entities with given encoding mode.\nSynonyms:\nglentities.encode\nglentities encode","url":"glentities.html#encode"},{"doc":"glentities","title":"encode_hex","content":"pub fn encode_hex(text: String) -&gt; String\n Encode text using HTML hex entities, except a-z, A-Z, 0-9, newline, tab, carriage return, and space.\nSynonyms:\nglentities.encode_hex\nglentities encode_hex","url":"glentities.html#encode_hex"},{"doc":"glentities","title":"encode_html_body","content":"pub fn encode_html_body(text: String, acc: StringBuilder) -&gt; String\n Encode text to be safe in the HTML body, inside element or attribute content.\n\n `&amp;`, `&lt;`, `&gt;`, `&#39;`, and `&quot;` are encoded.\n\n Note! Not suitable for outputting inside `&lt;style&gt;`, `&lt;script&gt;` elements.\nSynonyms:\nglentities.encode_html_body\nglentities encode_html_body","url":"glentities.html#encode_html_body"},{"doc":"glentities","title":"encode_named","content":"pub fn encode_named(text: String, acc: StringBuilder) -&gt; String\n Encode text using named HTML entities, except newline and tab. Characters without a named entity are untouched.\nSynonyms:\nglentities.encode_named\nglentities encode_named","url":"glentities.html#encode_named"},{"doc":"glentities","title":"glentities","content":"","url":"glentities.html"}]);